/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ValueHeaders.
 *
 * The Initial Developer of the Original Code is Karsten Düsterloh <mnyromyr@tprac.de>.
 *
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Karsten Düsterloh <mnyromyr@tprac.de>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the LGPL or the GPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

// |
// |  constants
// |
const gksName          = "ValueHeaders";
const gksVersion       = "1.0.0.0";  // major, minor, release, build > 0
const gksChromeName    = "valueheaders";
const gksContentDir    = "content/";

const gkoContentPacks  = {"valueheaders": ""}; // base package; must be named gksChromeName!
                         
// file names
const gksJar           = "valueheaders.jar";
// files and folders
const gkoProChrome     = getFolder("Profile", "chrome");
const gkoProChromeJar  = getFolder(gkoProChrome, gksJar);
const gkbProJarExists  = File.exists(gkoProChromeJar);
const gkoAppChrome     = getFolder("Chrome");
const gkoAppChromeJar  = getFolder(gkoAppChrome, gksJar);
const gkbAppJarExists  = File.exists(gkoAppChromeJar);
// string property names
const gksConfirmLoc    = "Location";
const gksAlertSuccess  = "Success";
const gksAlertFailure  = "Failure";
const gksAlertOldInst  = "OldInst";


// |
// |  variables
// |
var grsProperties      = null;    // array of localized string

// |
// |  helper functions
// |

function Init()
{
  grsProperties = {Location: "Soll ValueHeaders v1.0 ins Benutzerprofil installiert werden?\n\
                              Ein Mozilla-Update erfordert dann keine Neuinstallation mehr.\n\
                              Bei [Abbrechen] wird ins Mozilla-Verzeichnis installiert.",
                   Success : "ValueHeaders v1.0 wurde erfolgreich installiert.\n\
                              Zur vollst\u00E4ndigen Aktivierung mu\u00DF Mozilla neu gestartet werden!\n\
                              Bitte alle Fehler an <mnyromyr@tprac.de> melden.",
                   Failure : "Installation von ValueHeaders v1.0 fehlgeschlagen!\n\
                              (Fehlende Schreibrechte f\u00FCrs Chrome-Verzeichnis?)\nFehlernummer:",
                   OldInst : "Eine alte ValueHeaders-Version wurde gefunden!\n\
                              Sie mu\u00DF vor der Installation dieser Version entfernt werden!"};
  return !!grsProperties;
}


// main()
function InstallAddon()
{
  var iError = initInstall(gksName, gksChromeName, gksVersion);
  if (iError == SUCCESS)
  { // load localized properties file
    if (Init())
    {
      var bHaveContent = gkbProJarExists || gkbAppJarExists;
      var oChromeDir   = gkbProJarExists ? gkoProChrome   : gkoAppChrome;
      var iChrome      = gkbProJarExists ? PROFILE_CHROME : DELAYED_CHROME;
      { // where do we wanna install today?
        //   if we have already an installation -> cancel with uninstall request
        //                                         (if not overridden)
        //   otherwise                          -> ask where to install it
        //                                         (or use old, if overridden)
        // (an installation both in the app chrome and the profile chrome isn't
        //  possible with this install script, so we can ignore that case)
        // in any case, tell the user what we've found
        var bOverwrite = false;
        if (bHaveContent)
        {
          if (gbOverwrite)
          {
            bOverwrite   = true;
            bHaveContent = false;
          }
          else
            iError = ALREADY_EXISTS;
        }
        
        if (!bHaveContent)
        { // ask where to install (if not overwritten)
          if (bOverwrite)
            bProfile = gkbProJarExists; // in doubt, use profile
          else
            bProfile = confirm(grsProperties[gksConfirmLoc]);
  
          // copy the jar
          oChromeDir = bProfile ? gkoProChrome : gkoAppChrome;
          iError = addFile(gksName, gksVersion, gksJar, oChromeDir, null);
          if (iError == SUCCESS)
          { // register the chrome parts
            iChrome  = bProfile ? PROFILE_CHROME : DELAYED_CHROME;
            const koJarPath = bProfile ? gkoProChromeJar : gkoAppChromeJar;
            // register the content packs
            var sPath = gksContentDir;
            registerChrome(CONTENT | iChrome,  // app or profile
                           koJarPath,          // the main jar
                           sPath);             // content/mnenhy/headers/
            bHaveContent = true;
          } // register content
        }
      } // install content

      if (iError == SUCCESS)
        iError = performInstall(); // just do it!
    }
    else
    { // init failed
      iError = SOURCE_DOES_NOT_EXIST;
    }
  } // init install

  if (iError == SUCCESS || iError == REBOOT_NEEDED)
  {
    alert(grsProperties[gksAlertSuccess]);
  }
  else
  {
    if (iError == ALREADY_EXISTS)
      alert(grsProperties[gksAlertOldInst]);
    else
      alert(grsProperties[gksAlertFailure] + iError);
    cancelInstall(iError);
  }
}


// |
// |  start this installation script
// |
InstallAddon();
